@@ -28,11 +28,14 @@ def Slater_Koster( data_controller, params ):
   for ia in range(natoms):
     tau[ia] = np.array(params['model']['atoms'][str(ia)]['tau'])  
   atoms = []
+  shells = []
   for ia in range(natoms):
     atoms.append(params['model']['atoms'][str(ia)]['name'])
+    shells.append(params['model']['atoms'][str(ia)])
   arry['tau'] = tau
   arry['atoms'] = atoms
   attr['natoms'] = natoms
+  arry['shells'] = shells
   attr['nspin'] = 1 # only unpolarized case for now
   attr['dftSO'] = False # no spin-orbit
   
@@ -179,7 +182,7 @@ def graphene( data_controller, params ):
   attr['nspin'] = 1
   attr['natoms'] = 2
 
-  attr['alat'] = 2.46
+  attr['alat'] = 2.46 * ANGSTROM_AU
 
   arry['HRs'] = np.zeros((attr['nawf'],attr['nawf'],attr['nk1'],attr['nk2'],attr['nk3'],attr['nspin']),dtype=complex)
 
@@ -197,12 +200,12 @@ def graphene( data_controller, params ):
   arry['HRs'][1,0,0,1,0,0] = params['t']
 
   #H02
-  arry['HRs'][:,:,0,1,0,0] = np.conj(arry['HRs'][:,:,0,1,0,0]).T
+  arry['HRs'][:,:,0,2,0,0] = np.conj(arry['HRs'][:,:,0,1,0,0]).T
 
   # Lattice Vectors
   arry['a_vectors'] = np.zeros((3,3),dtype=float)
   arry['a_vectors'] = np.array([[1., 0, 0], [0.5, 3 ** .5 / 2, 0], [0, 0, 10]])
-  arry['a_vectors'] = arry['a_vectors']/ANGSTROM_AU
+  arry['a_vectors'] = arry['a_vectors']
 
   # Atomic coordinates
   arry['tau'] = np.zeros((2,3),dtype=float) 
@@ -218,7 +221,70 @@ def graphene( data_controller, params ):
   arry['b_vectors'][1,:] = (np.cross(arry['a_vectors'][2,:],arry['a_vectors'][0,:]))/volume
   arry['b_vectors'][2,:] = (np.cross(arry['a_vectors'][0,:],arry['a_vectors'][1,:]))/volume 
 
-  arry['species']=["C","C"]
+  arry['atoms']=['C','C']
+
+def graphene2( data_controller, params ):
+  from .constants import ANGSTROM_AU
+  from scipy.fftpack import fftshift
+  from mpi4py import MPI
+  import numpy as np
+
+  arry,attr = data_controller.data_dicts()
+
+  attr['nk1'] = 3
+  attr['nk2'] = 3
+  attr['nk3'] = 1
+
+  attr['nawf'] = 2
+  attr['nspin'] = 1
+  attr['natoms'] = 2
+
+  arry['naw'] = np.array([1,1])
+
+  attr['alat'] = 2.46 * ANGSTROM_AU
+
+  arry['HRs'] = np.zeros((attr['nawf'],attr['nawf'],attr['nk1'],attr['nk2'],attr['nk3'],attr['nspin']),dtype=complex)
+
+  # H00
+  arry['HRs'][0,0,0,0,0,0] = params['delta']/2
+  arry['HRs'][1,1,0,0,0,0] = -params['delta']/2
+
+  # H00
+  arry['HRs'][0,1,0,0,0,0] = params['t']
+  arry['HRs'][1,0,0,0,0,0] = params['t']
+
+  # H10
+  arry['HRs'][1,0,1,0,0,0] = params['t']
+
+  #H20
+  arry['HRs'][:,:,2,0,0,0] = np.conj(arry['HRs'][:,:,1,0,0,0]).T
+
+  #H01
+  arry['HRs'][1,0,0,1,0,0] = params['t']
+
+  #H02
+  arry['HRs'][:,:,0,2,0,0] = np.conj(arry['HRs'][:,:,0,1,0,0]).T
+
+  # Lattice Vectors
+  arry['a_vectors'] = np.zeros((3,3),dtype=float)
+  arry['a_vectors'] = np.array([[1., 0, 0], [0.5, 3 ** .5 / 2, 0], [0, 0, 10]])
+  arry['a_vectors'] = arry['a_vectors']
+
+  # Atomic coordinates
+  arry['tau'] = np.zeros((2,3),dtype=float) 
+
+  arry['tau'][0,0] = 0.50000 ;  arry['tau'][0,1] = 0.28867
+  arry['tau'][1,0] = 1.00000 ;  arry['tau'][1,1] = 0.57735
+
+
+  # Reciprocal Lattice
+  arry['b_vectors'] = np.zeros((3,3),dtype=float)
+  volume = np.dot(np.cross(arry['a_vectors'][0,:],arry['a_vectors'][1,:]),arry['a_vectors'][2,:])
+  arry['b_vectors'][0,:] = (np.cross(arry['a_vectors'][1,:],arry['a_vectors'][2,:]))/volume
+  arry['b_vectors'][1,:] = (np.cross(arry['a_vectors'][2,:],arry['a_vectors'][0,:]))/volume
+  arry['b_vectors'][2,:] = (np.cross(arry['a_vectors'][0,:],arry['a_vectors'][1,:]))/volume 
+
+  arry['atoms']=['C','C']
 
 
 def cubium( data_controller, params ):
@@ -232,23 +298,24 @@ def cubium( data_controller, params ):
   attr['nk1'] = 3
   attr['nk2'] = 3
   attr['nk3'] = 3
-
+  attr['Efermi'] = 6*params['t']
   attr['nawf'] = 1
   attr['nspin'] = 1
   attr['natoms'] = 1
   attr['bnd']=1
   attr['shift']=0
-  attr['omega']=1
   attr['dftSO']=False
   attr['nkpnts']=attr['nk1']*attr['nk2']*attr['nk3']
   attr['nbnds']=1
+  attr['nelec']=2
 
-  attr['alat'] = 1.0
+  attr['alat'] = 1.0*ANGSTROM_AU
+  attr['omega'] = attr['alat']**3
 
   arry['HRs'] = np.zeros((attr['nawf'],attr['nawf'],attr['nk1'],attr['nk2'],attr['nk3'],attr['nspin']),dtype=complex)
 
   # H000
-  arry['HRs'][0,0,0,0,0,0] = 0.0
+  arry['HRs'][0,0,0,0,0,0] = 0.0 - attr['Efermi']
 
   # H100
   arry['HRs'][0,0,1,0,0,0] = params['t']
@@ -271,7 +338,6 @@ def cubium( data_controller, params ):
   # Lattice Vectors
   arry['a_vectors'] = np.zeros((3,3),dtype=float)
   arry['a_vectors'] = np.array([[1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]])
-  arry['a_vectors'] = arry['a_vectors']/ANGSTROM_AU
 
   # Atomic coordinates
   arry['tau'] = np.zeros((1,3),dtype=float) 
@@ -302,18 +368,18 @@ def cubium2( data_controller, params ):
   attr['natoms'] = 1
   attr['bnd']=2
   attr['shift']=0
-  attr['omega']=1
   attr['dftSO']=False
   attr['nkpnts']=attr['nk1']*attr['nk2']*attr['nk3']
   attr['nbnds']=2
-
-  attr['alat'] = 1.0
+  attr['nelec']=2
+  attr['alat'] = 1.0*ANGSTROM_AU
+  attr['omega'] = attr['alat']**3
 
   arry['HRs'] = np.zeros((attr['nawf'],attr['nawf'],attr['nk1'],attr['nk2'],attr['nk3'],attr['nspin']),dtype=complex)
 
   # H000
-  arry['HRs'][0,0,0,0,0,0] = -params['Eg']/2 -6.0
-  arry['HRs'][1,1,0,0,0,0] = params['Eg']/2 +6.0
+  arry['HRs'][0,0,0,0,0,0] = -params['Eg']/2 -6.0*params['t']
+  arry['HRs'][1,1,0,0,0,0] = params['Eg']/2 +6.0*params['t']
 
   # H100
   arry['HRs'][0,0,1,0,0,0] = params['t']
@@ -339,7 +405,6 @@ def cubium2( data_controller, params ):
   # Lattice Vectors
   arry['a_vectors'] = np.zeros((3,3),dtype=float)
   arry['a_vectors'] = np.array([[1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]])
-  arry['a_vectors'] = arry['a_vectors']/ANGSTROM_AU
 
   # Atomic coordinates
   arry['tau'] = np.zeros((1,3),dtype=float) 
@@ -370,68 +435,103 @@ def Kane_Mele( data_controller, params ):
   attr['nspin'] = 1
   attr['natoms'] = 2
 
-  attr['alat'] = params['alat']
+  arry['naw'] = [2,2]
+
+  if 'alat' not in params: alat = 1.0
+  else: alat = params['alat']
+
+  attr['alat'] = alat * ANGSTROM_AU
+
+  t = params['t']
+  soc_par = params['soc_par']
+  r_par = params['r_par']
+  v_par = params['v_par']
 
   arry['HRs'] = np.zeros((attr['nawf'],attr['nawf'],attr['nk1'],attr['nk2'],attr['nk3'],attr['nspin']),dtype=complex)
 
   # H00
-  arry['HRs'][0,2,0,0,0,0]=params['t']
-  arry['HRs'][1,3,0,0,0,0]=params['t']
-  arry['HRs'][2,0,0,0,0,0]=params['t']
-  arry['HRs'][3,1,0,0,0,0]=params['t']
+  arry['HRs'][0,0,0,0,0,0] = t * v_par
+  arry['HRs'][1,1,0,0,0,0] = t * v_par
+  arry['HRs'][2,2,0,0,0,0] = -t * v_par
+  arry['HRs'][3,3,0,0,0,0] = -t * v_par
+
+  # H00
+  arry['HRs'][0,2,0,0,0,0] = t
+  arry['HRs'][1,3,0,0,0,0] = t
+  arry['HRs'][2,0,0,0,0,0] = t
+  arry['HRs'][3,1,0,0,0,0] = t
 
   # H10
-  arry['HRs'][2,0,1,0,0,0]=params['t']
-  arry['HRs'][3,1,1,0,0,0]=params['t']
+  arry['HRs'][2,0,1,0,0,0] = t
+  arry['HRs'][3,1,1,0,0,0] = t
 
-  arry['HRs'][0,0,1,0,0,0]=-complex(0.0,params['soc_par'])
-  arry['HRs'][1,1,1,0,0,0]=complex(0.0,params['soc_par'])
-  arry['HRs'][2,2,1,0,0,0]=complex(0.0,params['soc_par'])
-  arry['HRs'][3,3,1,0,0,0]=-complex(0.0,params['soc_par'])
+  arry['HRs'][0,0,1,0,0,0] = - complex(0.0,soc_par)
+  arry['HRs'][1,1,1,0,0,0] =   complex(0.0,soc_par)
+  arry['HRs'][2,2,1,0,0,0] =   complex(0.0,soc_par)
+  arry['HRs'][3,3,1,0,0,0] = - complex(0.0,soc_par)
 
-  #H20
-  arry['HRs'][:,:,2,0,0,0]=np.conj(arry['HRs'][:,:,1,0,0,0]).T
+  ##H20
+  #arry['HRs'][:,:,2,0,0,0] = np.conj(arry['HRs'][:,:,1,0,0,0]).T
 
   #H01
-  arry['HRs'][2,0,0,1,0,0]=params['t']
-  arry['HRs'][3,1,0,1,0,0]=params['t']
+  arry['HRs'][2,0,0,1,0,0] = t
+  arry['HRs'][3,1,0,1,0,0] = t
 
-  arry['HRs'][0,0,0,1,0,0]=complex(0.0,params['soc_par'])
-  arry['HRs'][1,1,0,1,0,0]=-complex(0.0,params['soc_par'])
-  arry['HRs'][2,2,0,1,0,0]=-complex(0.0,params['soc_par'])
-  arry['HRs'][3,3,0,1,0,0]=complex(0.0,params['soc_par'])
+  arry['HRs'][0,0,0,1,0,0] =   complex(0.0,soc_par)
+  arry['HRs'][1,1,0,1,0,0] = - complex(0.0,soc_par)
+  arry['HRs'][2,2,0,1,0,0] = - complex(0.0,soc_par)
+  arry['HRs'][3,3,0,1,0,0] =   complex(0.0,soc_par)
 
-
-  #H02
-  arry['HRs'][:,:,0,2,0,0]=np.conj(arry['HRs'][:,:,0,1,0,0]).T
+  ##H02
+  #arry['HRs'][:,:,0,2,0,0] = np.conj(arry['HRs'][:,:,0,1,0,0]).T
 
   #H21
-  arry['HRs'][0,0,2,1,0,0]=-complex(0.0,params['soc_par'])
-  arry['HRs'][1,1,2,1,0,0]=complex(0.0,params['soc_par'])
-  arry['HRs'][2,2,2,1,0,0]=complex(0.0,params['soc_par'])
-  arry['HRs'][3,3,2,1,0,0]=-complex(0.0,params['soc_par'])
+  arry['HRs'][0,0,2,1,0,0] = - complex(0.0,soc_par)
+  arry['HRs'][1,1,2,1,0,0] =   complex(0.0,soc_par)
+  arry['HRs'][2,2,2,1,0,0] =   complex(0.0,soc_par)
+  arry['HRs'][3,3,2,1,0,0] = - complex(0.0,soc_par)
 
+  ##H12
+  ##arry['HRs'][:,:,1,2,0,0] = np.conj(arry['HRs'][:,:,2,1,0,0]).T
+
+  r3h =np.sqrt(3.0)/2.0
+
+  arry['HRs'][0,3,0,0,0,0] += r_par * complex(-r3h,0.5) # 1j * r_par * (0.5 * 1 - r3h * -1j) 
+  arry['HRs'][1,2,0,0,0,0] += r_par * complex(r3h,0.5) #1j * r_par * (0.5 * 1 - r3h * 1j)
+  arry['HRs'][3,0,0,0,0,0] += r_par * complex(-r3h,-0.5)
+  arry['HRs'][2,1,0,0,0,0] += r_par * complex(r3h,-0.5)
+
+  arry['HRs'][0,3,1,0,0,0] += -r_par * complex(r3h,0.5) # -1j * r_par * (0.5 * 1 + r3h * -1j)
+  arry['HRs'][1,2,1,0,0,0] += -r_par * complex(-r3h,0.5) # -1j * r_par * (0.5 * 1 + r3h * 1j)
+
+  arry['HRs'][0,3,0,1,0,0] += complex(0.0,r_par) # -1j * r_par * -1 * 1
+  arry['HRs'][1,2,0,1,0,0] += complex(0.0,r_par) # -1j * r_par * -1 * 1
+
+  #H02
+  arry['HRs'][:,:,0,2,0,0] = np.conj(arry['HRs'][:,:,0,1,0,0]).T
+  #H20
+  arry['HRs'][:,:,2,0,0,0] = np.conj(arry['HRs'][:,:,1,0,0,0]).T
   #H12
-  arry['HRs'][:,:,1,2,0,0]=np.conj(arry['HRs'][:,:,2,1,0,0]).T
+  arry['HRs'][:,:,1,2,0,0] = np.conj(arry['HRs'][:,:,2,1,0,0]).T
 
   # Lattice Vectors
   arry['a_vectors'] = np.zeros((3,3),dtype=float)
   arry['a_vectors'] = np.array([[1., 0, 0], [0.5, 3 ** .5 / 2, 0], [0, 0, 10]])
-  arry['a_vectors'] = arry['a_vectors']/ANGSTROM_AU
+  arry['a_vectors'] = arry['a_vectors']
 
   # Atomic coordinates
-  arry['tau'] = np.zeros((2,3),dtype=float) 
-
-  arry['tau'][0,0] = 0.50000 ;  arry['tau'][0,1] = 0.28867
-  arry['tau'][1,0] = 1.00000 ;  arry['tau'][1,1] = 0.57735
-
+  arry['tau'] = np.zeros((2,3),dtype=float)
+  arry['tau'][0] = np.dot([1/3,1/3,0.],arry['a_vectors'])
+  arry['tau'][1] = np.dot([2/3,2/3,0.],arry['a_vectors'])
 
   # Reciprocal Lattice
   arry['b_vectors'] = np.zeros((3,3),dtype=float)
   volume = np.dot(np.cross(arry['a_vectors'][0,:],arry['a_vectors'][1,:]),arry['a_vectors'][2,:])
   arry['b_vectors'][0,:] = (np.cross(arry['a_vectors'][1,:],arry['a_vectors'][2,:]))/volume
   arry['b_vectors'][1,:] = (np.cross(arry['a_vectors'][2,:],arry['a_vectors'][0,:]))/volume
-  arry['b_vectors'][2,:] = (np.cross(arry['a_vectors'][0,:],arry['a_vectors'][1,:]))/volume 
+  arry['b_vectors'][2,:] = (np.cross(arry['a_vectors'][0,:],arry['a_vectors'][1,:]))/volume
+
+  attr['omega'] = alat**3 * arry['a_vectors'][0,:].dot(np.cross(arry['a_vectors'][1,:],arry['a_vectors'][2,:]))
 
   arry['species']=["KM","KM"]
 
@@ -439,6 +539,8 @@ def Kane_Mele( data_controller, params ):
 def build_TB_model ( data_controller, parameters ):
   if parameters['label'].upper() == 'GRAPHENE':
     graphene(data_controller, parameters)
+  elif parameters['label'].upper() == 'GRAPHENE2':
+    graphene2(data_controller, parameters)
   elif parameters['label'].upper() == 'CUBIUM':
     cubium(data_controller, parameters)
   elif parameters['label'].upper() == 'CUBIUM2':
